﻿using Microsoft.Extensions.Logging;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using System.Xml.Linq;
using TransportCompanyContracts.BindingModels;
using TransportCompanyContracts.BusinessLogicsContracts;

namespace TransportCompany
{
	public partial class FormRandomCreateTrucking : Form
	{
		Random rnd = new Random(DateTime.Now.ToString().GetHashCode());

		private readonly IClientLogic _logicCl;

		private readonly ITransportLogic _logicTransport;

		private readonly ITransportationLogic _logicTransportation;

		private readonly ICargoLogic _logicCargo;

		private readonly ITruckingLogic _logic;

		private int? _id;

		public int Id { set { _id = value; } }

		public FormRandomCreateTrucking(ILogger<FormRandomCreateTrucking> logger, ITruckingLogic logic, ICargoLogic logicCargo,
			IClientLogic logicCl, ITransportLogic logicTransport, ITransportationLogic logicTransportation)
		{
			InitializeComponent();

			_logic = logic;
			_logicCargo = logicCargo;
			_logicCl = logicCl;
			_logicTransport = logicTransport;
			_logicTransportation = logicTransportation;
		}

		private void ButtonCreate_Click(object sender, EventArgs e)
		{
			var viewClient = _logicCl.ReadList(null);
			var viewCargo = _logicCargo.ReadList(null);
			var viewTransport = _logicTransport.ReadList(null);
			var viewTransportation = _logicTransportation.ReadList(null);

			try
			{
				for (int i = 0; i < Convert.ToInt32(textBoxCount.Text); i++)
				{
					DateTime dateStart = new DateTime(rnd.Next(1991, 2023), rnd.Next(1, 12), rnd.Next(1, 28));
					DateTime dateEnd = dateStart.AddDays(20);

					var model = new TruckingBindingModel
					{
						Id = 0,
						ClientId = viewClient[rnd.Next(0, viewClient.Count)].Id,
						CargoId = viewCargo[rnd.Next(0, viewCargo.Count)].Id,
						TransportId = viewTransport[rnd.Next(0, viewTransport.Count)].Id,
						TransportationId = viewTransportation[rnd.Next(0, viewTransportation.Count)].Id,
						DateStart = dateStart,
						DateEnd = dateEnd,
						Price = viewClient.Count * rnd.Next(100, 5000)
					};

					var operationResult = _logic.Create(model);

					if (!operationResult)
					{
						throw new Exception("Ошибка при сохранении. Дополнительная информация в логах.");
					}

					Close();
				}
			}
			catch (Exception ex)
			{
				MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
			}
		}

		private void ButtonCancel_Click(object sender, EventArgs e)
		{
			DialogResult = DialogResult.Cancel;
			Close();
		}
	}
}
